==> opensaml-saml-impl-3.4.6-sources.jar: org/opensaml/saml/ext/saml2delrestrict/impl/DelegationRestrictionTypeBuilder.java <==
/*
 * Licensed to the University Corporation for Advanced Internet Development,
 * Inc. (UCAID) under one or more contributor license agreements.  See the
 * NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The UCAID licenses this file to You under the Apache
 * License, Version 2.0 (the "License"); you may not use this file except in
 * compliance with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 * 
 */

package org.opensaml.saml.ext.saml2delrestrict.impl;

import org.opensaml.saml.common.AbstractSAMLObjectBuilder;
import org.opensaml.saml.ext.saml2delrestrict.DelegationRestrictionType;

/**
 * Builder of {@link DelegationRestrictionType}.
 */
public class DelegationRestrictionTypeBuilder extends AbstractSAMLObjectBuilder<DelegationRestrictionType> {

    /**
     * Constructor.
     */
    public DelegationRestrictionTypeBuilder() {

    }
    
    /** {@inheritDoc} */
    public DelegationRestrictionType buildObject() {
        return buildObject(DelegationRestrictionType.DEFAULT_ELEMENT_NAME, DelegationRestrictionType.TYPE_NAME);
    }

    /** {@inheritDoc} */
    public DelegationRestrictionType buildObject(final String namespaceURI, final String localName,
            final String namespacePrefix) {
        return new DelegationRestrictionTypeImpl(namespaceURI, localName, namespacePrefix);
    }

}

==> opensaml-saml-impl-5.0.0-sources.jar: org/opensaml/saml/ext/saml2delrestrict/impl/DelegationRestrictionTypeBuilder.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 * 
 */

package org.opensaml.saml.ext.saml2delrestrict.impl;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;

import org.opensaml.saml.common.AbstractSAMLObjectBuilder;
import org.opensaml.saml.ext.saml2delrestrict.DelegationRestrictionType;

/**
 * Builder of {@link DelegationRestrictionType}.
 */
public class DelegationRestrictionTypeBuilder extends AbstractSAMLObjectBuilder<DelegationRestrictionType> {
    
    /** {@inheritDoc} */
    @Override
    @Nonnull public DelegationRestrictionType buildObject() {
        return buildObject(DelegationRestrictionType.DEFAULT_ELEMENT_NAME, DelegationRestrictionType.TYPE_NAME);
    }

    /** {@inheritDoc} */
    @Override
    @Nonnull public DelegationRestrictionType buildObject(@Nullable final String namespaceURI,
            @Nonnull final String localName, @Nullable final String namespacePrefix) {
        return new DelegationRestrictionTypeImpl(namespaceURI, localName, namespacePrefix);
    }

}
